<a
  class="{{ view.color|default('') }} {{ extra_class|default('') }} waves-effect waves-light btn-floating"
  href="{{ view.url }}"
  title="{{ view.title }}"
  {% if view.link_attributes %}
  {% for key, value in view.link_attributes.items() %}
  {{ key }}="{{ value }}"
  {% endfor %}
  {% endif %}
  {% if view.controller %}
  data-controller="{{ view.controller }}"
  {% endif %}
  {% if view.action %}
  data-action="{{ view.action }}"
  {% endif %}
  ><i class="material-icons">{{ view.material_icon }}</i>
</a>
